# OASIS-GUI

![OASIS-GUI Screenshot](https://gitlab.com/oasis-acquisition/oasis-gui/-/raw/main/oasis_gui.png)

This Python package contains the GUI for interacting with the Open Acquisition System for IEPE Sensors (OASIS). 

## Installation

To install the OASIS-GUI through pip, use the following command:

`pip install oasis-gui`

## Opening the GUI

Open a terminal/command prompt with access to the Python PATH and type:

`oasis-gui`

## Currently supported boards

- OASIS-UROS Version 1.x